@@ -1,5 +1,5 @@
 # coding: utf-8
-from .tables import Table, TableBase
+from .tables import Table, TableBase, table_factory
 from .columns import (BooleanColumn, Column, CheckBoxColumn, DateColumn,
                       DateTimeColumn, EmailColumn, FileColumn, JSONColumn,
                       LinkColumn, ManyToManyColumn, RelatedLinkColumn, TemplateColumn,
@@ -9,10 +9,10 @@ from .utils import A
 from .views import SingleTableMixin, SingleTableView, MultiTableMixin
 
 
-__version__ = '1.14.2'
+__version__ = '1.21.2'
 
 __all__ = (
-    'Table', 'TableBase',
+    'Table', 'TableBase', 'table_factory',
     'BooleanColumn', 'Column', 'CheckBoxColumn', 'DateColumn', 'DateTimeColumn',
     'EmailColumn', 'FileColumn', 'JSONColumn', 'LinkColumn', 'ManyToManyColumn',
     'RelatedLinkColumn', 'TemplateColumn', 'TimeColumn', 'URLColumn',
