@@ -3,25 +3,24 @@ from __future__ import absolute_import, unicode_literals
 
 from django.db import models
 
+from django_tables2.templatetags.django_tables2 import title
+
 from .base import library
 from .linkcolumn import BaseLinkColumn
 
 
 @library.register
 class EmailColumn(BaseLinkColumn):
-    """
-    A subclass of `.BaseLinkColumn` that renders the cell value as a hyperlink.
+    '''
+    Render email addresses to mailto-links.
 
-    It's common to have a email value in a row hyperlinked to another page.
+    Arguments:
+        attrs (dict): HTML attributes that are added to the rendered
+            ``<a href="...">...</a>`` tag
+        text: Either static text, or a callable. If set, this will be used to
+            render the text inside link instead of the value
 
-    :param  attrs: a `dict` of HTML attributes that are added to the rendered
-                   ``<a href="...">...</a>`` tag
-    :param   text: Either static text, or a callable. If set, this value will be
-                   used to render the text inside link instead of value (default)
-
-    Example:
-
-    .. code-block:: python
+    Example::
 
         # models.py
         class Person(models.Model):
@@ -33,7 +32,9 @@ class EmailColumn(BaseLinkColumn):
             name = tables.Column()
             email = tables.EmailColumn()
 
-    """
+        # result
+        # [...]<a href="mailto:email@example.com">email@example.com</a>
+    '''
     def render(self, record, value):
         return self.render_link(
             uri='mailto:{}'.format(value),
@@ -44,4 +45,4 @@ class EmailColumn(BaseLinkColumn):
     @classmethod
     def from_field(cls, field):
         if isinstance(field, models.EmailField):
-            return cls(verbose_name=field.verbose_name)
+            return cls(verbose_name=title(field.verbose_name))
