@@ -18,6 +18,7 @@ class TemplateColumn(Column):
     Arguments:
         template_code (str): template code to render
         template_name (str): name of the template to render
+        extra_context (dict): optional extra template context
 
     A `~django.template.Template` object is created from the
     *template_code* or *template_name* and rendered with a context containing:
@@ -26,6 +27,7 @@ class TemplateColumn(Column):
     - *value*       -- value from `record` that corresponds to the current column
     - *default*     -- appropriate default value to use as fallback
     - *row_counter* -- The number of the row this cell is being rendered in.
+    - any context variables passed using the `extra_context` argument to `TemplateColumn`.
 
     Example:
 
@@ -33,17 +35,19 @@ class TemplateColumn(Column):
 
         class ExampleTable(tables.Table):
             foo = tables.TemplateColumn('{{ record.bar }}')
-            # contents of `myapp/bar_column.html` is `{{ value }}`
-            bar = tables.TemplateColumn(template_name='myapp/name2_column.html')
+            # contents of `myapp/bar_column.html` is `{{ label }}: {{ value }}`
+            bar = tables.TemplateColumn(template_name='myapp/name2_column.html',
+                                        extra_context={'label': 'Label'})
 
     Both columns will have the same output.
     '''
     empty_values = ()
 
-    def __init__(self, template_code=None, template_name=None, **extra):
+    def __init__(self, template_code=None, template_name=None, extra_context=None, **extra):
         super(TemplateColumn, self).__init__(**extra)
         self.template_code = template_code
         self.template_name = template_name
+        self.extra_context = extra_context or {}
 
         if not self.template_code and not self.template_name:
             raise ValueError('A template must be provided')
@@ -52,6 +56,7 @@ class TemplateColumn(Column):
         # If the table is being rendered using `render_table`, it hackily
         # attaches the context to the table as a gift to `TemplateColumn`.
         context = getattr(table, 'context', Context())
+        context.update(self.extra_context)
         context.update({
             'default': bound_column.default,
             'column': bound_column,
