@@ -20,10 +20,8 @@ class RequestConfig(object):
             A special *silent* item can be used to enable automatic handling of
             pagination exceptions using the following logic:
 
-             - If `~django.core.paginator.PageNotAnInteger` is raised, show the
-               first page.
-             - If `~django.core.paginator.EmptyPage` is raised, show the last
-               page.
+             - If `~django.core.paginator.PageNotAnInteger` is raised, show the first page.
+             - If `~django.core.paginator.EmptyPage` is raised, show the last page.
 
     '''
     def __init__(self, request, paginate=True):
@@ -63,3 +61,5 @@ class RequestConfig(object):
                     table.page = table.paginator.page(1)
                 except EmptyPage:
                     table.page = table.paginator.page(table.paginator.num_pages)
+
+        return table
