@@ -2,12 +2,12 @@
 from __future__ import unicode_literals
 
 import copy
+import warnings
 from collections import OrderedDict
 from itertools import count
 
 from django.conf import settings
 from django.core.paginator import Paginator
-from django.db.models.fields import FieldDoesNotExist
 from django.template.loader import get_template
 from django.utils import six
 from django.utils.encoding import force_text
@@ -16,7 +16,7 @@ from . import columns
 from .config import RequestConfig
 from .data import TableData
 from .rows import BoundRows
-from .utils import AttributeDict, OrderBy, OrderByTuple, Sequence
+from .utils import Accessor, AttributeDict, OrderBy, OrderByTuple, Sequence
 
 
 class DeclarativeColumnsMetaclass(type):
@@ -59,13 +59,8 @@ class DeclarativeColumnsMetaclass(type):
                 # Each item in opts.fields is the name of a model field or a
                 # normal attribute on the model
                 for field_name in opts.fields:
-                    try:
-                        field = opts.model._meta.get_field(field_name)
-                    except FieldDoesNotExist:
-                        extra[field_name] = columns.Column()
-                    else:
-                        extra[field_name] = columns.library.column_for_field(field)
-
+                    field = Accessor(field_name).get_field(opts.model)
+                    extra[field_name] = columns.library.column_for_field(field)
             else:
                 for field in opts.model._meta.fields:
                     extra[field.name] = columns.library.column_for_field(field)
@@ -141,7 +136,11 @@ class TableOptions(object):
         self.sequence = Sequence(getattr(options, 'sequence', ()))
         self.orderable = getattr(options, 'orderable', True)
         self.model = getattr(options, 'model', None)
-        self.template = getattr(options, 'template', DJANGO_TABLES2_TEMPLATE)
+        if hasattr(options, 'template'):
+            self.template_name = getattr(options, 'template', DJANGO_TABLES2_TEMPLATE)
+            warnings.warn('Table.Meta.template is deprecated. Use template_name instead.', DeprecationWarning)
+        else:
+            self.template_name = getattr(options, 'template_name', DJANGO_TABLES2_TEMPLATE)
         self.localize = getattr(options, 'localize', ())
         self.unlocalize = getattr(options, 'unlocalize', ())
 
@@ -195,8 +194,9 @@ class TableBase(object):
         per_page_field (str): If not `None`, defines the name of the *per page*
             querystring field.
 
-        template (str): The template to render when using ``{% render_table %}``
-            (default ``'django_tables2/table.html'``)
+        template_name (str): The template to render when using ``{% render_table %}``
+            (defaults to DJANGO_TABLES2_TEMPLATE, which is ``'django_tables2/table.html'``
+            by default).
 
         default (str): Text to render in empty cells (determined by
             `.Column.empty_values`, default `.Table.Meta.default`)
@@ -215,7 +215,7 @@ class TableBase(object):
     def __init__(self, data=None, order_by=None, orderable=None, empty_text=None,
                  exclude=None, attrs=None, row_attrs=None, pinned_row_attrs=None,
                  sequence=None, prefix=None, order_by_field=None, page_field=None,
-                 per_page_field=None, template=None, default=None, request=None,
+                 per_page_field=None, template=None, template_name=None, default=None, request=None,
                  show_header=None, show_footer=True, extra_columns=None):
         super(TableBase, self).__init__()
 
@@ -226,7 +226,8 @@ class TableBase(object):
 
         self.exclude = exclude or self._meta.exclude
         self.sequence = sequence
-        self.data = TableData.from_data(data=data, table=self)
+        self.data = TableData.from_data(data=data)
+        self.data.table = self
         if default is None:
             default = self._meta.default
         self.default = default
@@ -280,7 +281,6 @@ class TableBase(object):
         base_columns = OrderedDict((
             (x, base_columns[x]) for x in sequence if x in base_columns
         ))
-
         self.columns = columns.BoundColumns(self, base_columns)
         # `None` value for order_by means no order is specified. This means we
         # `shouldn't touch our data's ordering in any way. *However*
@@ -297,7 +297,11 @@ class TableBase(object):
                 self.order_by = order_by
         else:
             self.order_by = order_by
-        self.template = template
+        if template is not None:
+            self.template_name = template
+            warnings.warn('template argument to Table is deprecated. Use template_name instead.', DeprecationWarning)
+        else:
+            self.template_name = template_name
         # If a request is passed, configure for request
         if request:
             RequestConfig(request).configure(self)
@@ -383,7 +387,7 @@ class TableBase(object):
         '''
         # reset counter for new rendering
         self._counter = count()
-        template = get_template(self.template)
+        template = get_template(self.template_name)
 
         context = {
             'table': self,
@@ -574,16 +578,25 @@ class TableBase(object):
         self._orderable = value
 
     @property
-    def template(self):
+    def template_name(self):
         if self._template is not None:
             return self._template
         else:
-            return self._meta.template
+            return self._meta.template_name
 
-    @template.setter
-    def template(self, value):
+    @template_name.setter
+    def template_name(self, value):
         self._template = value
 
+    @property
+    def paginated_rows(self):
+        '''
+        Return the rows for the current page if the table is paginated, else all rows.
+        '''
+        if hasattr(self, 'page'):
+            return self.page.object_list
+        return self.rows
+
     def get_column_class_names(self, classes_set, bound_column):
         '''
         Returns a set of HTML class names for cells (both td and th) of a
@@ -617,3 +630,41 @@ class Table(TableBase):
     __doc__ = TableBase.__doc__
 
 # Table = DeclarativeColumnsMetaclass(str('Table'), (TableBase, ), {})
+
+
+def table_factory(model, table=Table, fields=None, exclude=None,
+                  localize=None):
+    """
+    Returns Table class for given `model`, equivalent to defining a custom table class::
+
+        class MyTable(tables.Table):
+            class Meta:
+                model = model
+
+    Arguments:
+        model (`~django.db.models.Model`): Model associated with the new table
+        table (`.Table`): Base Table class used to create the new one
+        fields (list of str): Fields displayed in tables
+        exclude (list of str): Fields exclude in tables
+        localize (list of str): Fields to localize
+    """
+    attrs = {'model': model}
+    if fields is not None:
+        attrs['fields'] = fields
+    if exclude is not None:
+        attrs['exclude'] = exclude
+    if localize is not None:
+        attrs['localize'] = localize
+    # If parent form class already has an inner Meta, the Meta we're
+    # creating needs to inherit from the parent's inner meta.
+    parent = (object,)
+    if hasattr(table, 'Meta'):
+        parent = (table.Meta, object)
+    Meta = type(str('Meta'), parent, attrs)
+    # Give this new table class a reasonable name.
+    class_name = model.__name__ + str('Table')
+    # Class attributes for the new table class.
+    table_class_attrs = {
+        'Meta': Meta,
+    }
+    return type(table)(class_name, (table,), table_class_attrs)
