@@ -1,9 +1,11 @@
 # coding: utf-8
 from __future__ import absolute_import, unicode_literals
 
+from collections import OrderedDict
 from functools import total_ordering
 from itertools import chain
 
+from django.db import models
 from django.db.models.fields import FieldDoesNotExist
 from django.utils import six
 from django.utils.html import format_html_join
@@ -278,6 +280,9 @@ class Accessor(str):
     '''
     SEPARATOR = '.'
 
+    ALTERS_DATA_ERROR_FMT = 'Refusing to call {method}() because `.alters_data = True`'
+    LOOKUP_ERROR_FMT = 'Failed lookup for key [{key}] in {context}, when resolving the accessor {accessor}'
+
     def resolve(self, context, safe=True, quiet=False):
         '''
         Return an object described by the accessor by traversing the attributes
@@ -313,6 +318,7 @@ class Accessor(str):
             TypeError`, `AttributeError`, `KeyError`, `ValueError`
             (unless `quiet` == `True`)
         '''
+
         try:
             current = context
             for bit in self.bits:
@@ -329,13 +335,16 @@ class Accessor(str):
                                 KeyError,    # dict without `int(bit)` key
                                 TypeError,   # unsubscriptable object
                                 ):
-                            raise ValueError('Failed lookup for key [%s] in %r'
-                                             ', when resolving the accessor %s' % (bit, current, self)
-                                             )
+                            current_context = type(current) if isinstance(current, models.Model) else current
+
+                            raise ValueError(
+                                self.LOOKUP_ERROR_FMT.format(key=bit, context=current_context, accessor=self)
+                            )
                 if callable(current):
                     if safe and getattr(current, 'alters_data', False):
-                        raise ValueError('refusing to call %s() because `.alters_data = True`'
-                                         % repr(current))
+                        raise ValueError(
+                            self.ALTERS_DATA_ERROR_FMT.format(method=repr(current))
+                        )
                     if not getattr(current, 'do_not_call_in_templates', False):
                         current = current()
                 # important that we break in None case, or a relationship
@@ -372,12 +381,6 @@ class Accessor(str):
                 rel = getattr(field, 'remote_field', None)
                 model = getattr(rel, 'model', model)
 
-            # !!! Support only for Django <= 1.8
-            # Remove this when support for Django 1.8 is over
-            else:
-                rel = getattr(field, 'rel', None)
-                model = getattr(rel, 'to', model)
-
         return field
 
     def penultimate(self, context, quiet=True):
@@ -399,10 +402,12 @@ class Accessor(str):
 A = Accessor  # alias
 
 
-class AttributeDict(dict):
+class AttributeDict(OrderedDict):
     '''
-    A wrapper around `dict` that knows how to render itself as HTML
-    style tag attributes.
+    A wrapper around `collections.OrderedDict` that knows how to render itself
+    as HTML style tag attributes.
+
+    Any key with ``value is None`` will be skipped.
 
     The returned string is marked safe, so it can be used safely in a template.
     See `.as_html` for a usage example.
@@ -411,8 +416,9 @@ class AttributeDict(dict):
 
     def _iteritems(self):
         for k, v in six.iteritems(self):
-            if k not in self.blacklist:
-                yield (k, v() if callable(v) else v)
+            value = v() if callable(v) else v
+            if k not in self.blacklist and value is not None:
+                yield (k, value)
 
     def as_html(self):
         '''
@@ -427,7 +433,7 @@ class AttributeDict(dict):
             >>> attrs.as_html()
             'class="mytable" id="someid"'
 
-        :rtype: `~django.utils.safestring.SafeUnicode` object
+        returns: `~django.utils.safestring.SafeUnicode` object
 
         '''
         return format_html_join(' ', '{}="{}"', self._iteritems())
@@ -513,11 +519,19 @@ def call_with_appropriate(fn, kwargs):
 
     If the kwargs argument is defined, pass all arguments, else provide exactly
     the arguments wanted.
+
+    If one of the arguments of ``fn`` are not contained in kwargs, ``fn`` will not
+    be called and ``None`` will be returned.
     '''
-    args, keyword = signature(fn)
-    if not keyword:
+    args, kwargs_name = signature(fn)
+    # no catch-all defined, we need to exactly pass the arguments specified.
+    if not kwargs_name:
         kwargs = {key: kwargs[key] for key in kwargs if key in args}
 
+        # if any argument of fn is not in kwargs, just return None
+        if any(arg not in kwargs for arg in args):
+            return None
+
     return fn(**kwargs)
 
 
