@@ -6,28 +6,17 @@ from itertools import count
 from django.core.exceptions import ImproperlyConfigured
 from django.views.generic.list import ListView
 
+from . import tables
 from .config import RequestConfig
 
 
 class TableMixinBase(object):
     '''
-    Base mixin for table-related class based views.
+    Base mixin for the Single- and MultiTable class based views
     '''
-
     context_table_name = 'table'
     table_pagination = None
 
-    def get_table_class(self):
-        '''
-        Return the class to use for the table.
-        '''
-        if self.table_class:
-            return self.table_class
-        klass = type(self).__name__
-        raise ImproperlyConfigured(
-            'A table class was not specified. Define {}.table_class'.format(klass)
-        )
-
     def get_context_table_name(self, table):
         '''
         Get the name to use for the table's template variable.
@@ -65,14 +54,33 @@ class SingleTableMixin(TableMixinBase):
             'table')
         table_pagination (dict): controls table pagination. If a `dict`, passed as
             the *paginate* keyword argument to `.RequestConfig`. As such, any
-            Truthy value enables pagination. (default: enable pagination)
+            Truthy value enables pagination. (default: enable pagination).
 
-    This mixin plays nice with the Django's`.MultipleObjectMixin` by using
-    `.get_queryset`` as a fallback for the table data source.
+            The `dict` can be used to specify values for arguments for the call to
+            `~.tables.Table.paginate`.
+
+            If you want to use a non-standard paginator for example, you can add a key
+            `klass` to the dict, containing a custom `Pagintor` class.
+
+    This mixin plays nice with the Django's ``.MultipleObjectMixin`` by using
+    ``.get_queryset`` as a fallback for the table data source.
     '''
     table_class = None
     table_data = None
 
+    def get_table_class(self):
+        '''
+        Return the class to use for the table.
+        '''
+        if self.table_class:
+            return self.table_class
+        if self.model:
+            return tables.table_factory(self.model)
+
+        raise ImproperlyConfigured(
+            'You must either specify {0}.table_class or {0}.model'.format(type(self).__name__)
+        )
+
     def get_table(self, **kwargs):
         '''
         Return a table object to use. The table has automatic support for
@@ -80,8 +88,7 @@ class SingleTableMixin(TableMixinBase):
         '''
         table_class = self.get_table_class()
         table = table_class(data=self.get_table_data(), **kwargs)
-        RequestConfig(self.request, paginate=self.get_table_pagination(table)).configure(table)
-        return table
+        return RequestConfig(self.request, paginate=self.get_table_pagination(table)).configure(table)
 
     def get_table_data(self):
         '''
@@ -103,8 +110,8 @@ class SingleTableMixin(TableMixinBase):
         '''
         Return the keyword arguments for instantiating the table.
 
-        Allows passing customized arguments to the table constructor, for example, to remove the buttons column,
-        you could define this method in your View::
+        Allows passing customized arguments to the table constructor, for example,
+        to remove the buttons column, you could define this method in your View::
 
             def get_table_kwargs(self):
                 return {
@@ -127,18 +134,21 @@ class SingleTableMixin(TableMixinBase):
 class SingleTableView(SingleTableMixin, ListView):
     '''
     Generic view that renders a template and passes in a `.Table` instances.
+
+    Mixes ``.SingleTableMixin`` with ``django.views.generic.list.ListView``.
     '''
 
 
 class MultiTableMixin(TableMixinBase):
     '''
-    Adds a Table object to the context. Typically used with
+    Add a list with multiple Table object's to the context. Typically used with
     `.TemplateResponseMixin`.
 
-    the `tables` attribute must be either a list of `.Table` instances or
+    The `tables` attribute must be either a list of `.Table` instances or
     classes extended from `.Table` which are not already instantiated. In that
-    case, tables_data must be defined, having an entry containing the data for
-    each table in `tables`.
+    case, `get_tables_data` must be able to return the tables data, either by
+    having an entry containing the data for each table in `tables`, or by
+    overriding this method in order to return this data.
 
     Attributes:
         tables: list of `.Table` instances or list of `.Table` child objects.
@@ -162,27 +172,36 @@ class MultiTableMixin(TableMixinBase):
     context_table_name = 'tables'
 
     def get_tables(self):
-        if not self.tables:
-            klass = type(self).__name__
-            raise ImproperlyConfigured(
-                'No tables were specified. Define {}.tables'.format(klass)
-            )
+        '''
+        Return an array of table instances containing data.
+        '''
+        data = self.get_tables_data()
 
-        return self.tables
+        if data is None:
+            if not self.tables:
+                klass = type(self).__name__
+                raise ImproperlyConfigured(
+                    'No tables were specified. Define {}.tables'.format(klass)
+                )
 
-    def get_context_data(self, **kwargs):
-        context = super(MultiTableMixin, self).get_context_data(**kwargs)
-
-        if self.tables_data is None:
-            tables = self.get_tables()
+            return self.tables
         else:
-            data = self.tables_data
-            if len(data) != len(self.get_tables()):
+            if len(data) != len(self.tables):
                 klass = type(self).__name__
                 raise ImproperlyConfigured(
                     'len({}.tables_data) != len({}.tables)'.format(klass, klass)
                 )
-            tables = list(Table(data[i]) for i, Table in enumerate(self.tables))
+            return list(Table(data[i]) for i, Table in enumerate(self.tables))
+
+    def get_tables_data(self):
+        '''
+        Return an array of table_data that should be used to populate each table
+        '''
+        return self.tables_data
+
+    def get_context_data(self, **kwargs):
+        context = super(MultiTableMixin, self).get_context_data(**kwargs)
+        tables = self.get_tables()
 
         # apply prefixes and execute requestConfig for each table
         table_counter = count()
