@@ -2,9 +2,12 @@
 from __future__ import unicode_literals
 
 from django.db import models
+from django.urls import reverse
+from django.utils.encoding import python_2_unicode_compatible
 from django.utils.translation import ugettext_lazy as _
 
 
+@python_2_unicode_compatible
 class Country(models.Model):
     '''
     Represents a geographical Country
@@ -19,25 +22,26 @@ class Country(models.Model):
     class Meta:
         verbose_name_plural = _('countries')
 
-    def __unicode__(self):
+    def __str__(self):
         return self.name
 
     def get_absolute_url(self):
-        return 'country/%d' % self.pk
+        return reverse('country_detail', args=(self.pk, ))
 
     @property
     def summary(self):
         return '%s (pop. %s)' % (self.name, self.population)
 
 
+@python_2_unicode_compatible
 class Person(models.Model):
     name = models.CharField(max_length=200, verbose_name='full name')
     friendly = models.BooleanField(default=True)
 
-    country = models.ForeignKey(Country, null=True)
+    country = models.ForeignKey(Country, null=True, on_delete=models.CASCADE)
 
     class Meta:
         verbose_name_plural = 'people'
 
-    def __unicode__(self):
+    def __str__(self):
         return self.name
