@@ -4,18 +4,11 @@ from __future__ import unicode_literals
 from django.contrib.contenttypes.fields import GenericForeignKey
 from django.contrib.contenttypes.models import ContentType
 from django.db import models
+from django.urls import reverse
 from django.utils import six
 from django.utils.safestring import mark_safe
 from django.utils.translation import ugettext, ugettext_lazy
 
-from haystack import indexes
-
-try:
-    from django.urls import reverse
-except ImportError:
-    # to keep backward (Django <= 1.9) compatibility
-    from django.core.urlresolvers import reverse
-
 
 @six.python_2_unicode_compatible
 class Person(models.Model):
@@ -84,8 +77,8 @@ class PersonProxy(Person):
 class Occupation(models.Model):
     name = models.CharField(max_length=200)
     region = models.ForeignKey('Region', null=True, on_delete=models.CASCADE)
-    boolean = models.BooleanField(null=True)
-    boolean_with_choices = models.BooleanField(null=True, choices=(
+    boolean = models.NullBooleanField(null=True)
+    boolean_with_choices = models.NullBooleanField(null=True, choices=(
         (True, 'Yes'),
         (False, 'No')
     ))
@@ -113,15 +106,3 @@ class PersonInformation(models.Model):
         verbose_name='Information',
         on_delete=models.CASCADE
     )
-
-
-# -- haystack -----------------------------------------------------------------
-
-class PersonIndex(indexes.SearchIndex, indexes.Indexable):
-    first_name = indexes.CharField(document=True)
-
-    def get_model(self):
-        return Person
-
-    def index_queryset(self, using=None):
-        return self.get_model().objects.all()
