@@ -10,7 +10,6 @@ INSTALLED_APPS = [
     'django.contrib.contenttypes',
     'django.contrib.auth',
     'django_tables2',
-    'haystack',
 ]
 
 ROOT_URLCONF = 'tests.app.urls'
@@ -32,9 +31,3 @@ TEMPLATES = [
 TIME_ZONE = "Australia/Brisbane"
 
 USE_TZ = True
-
-HAYSTACK_CONNECTIONS = {
-    'default': {
-        'ENGINE': 'haystack.backends.simple_backend.SimpleEngine',
-    }
-}
