@@ -1,7 +1,8 @@
 # coding: utf-8
-from django.shortcuts import get_object_or_404
 from django.http import HttpResponse
-from .models import Person, Occupation
+from django.shortcuts import get_object_or_404
+
+from .models import Occupation, Person
 
 
 def person(request, pk):
